==> nailgun_7.0.0.orig.tar.gz: nailgun/static/i18n.js <==
/*
 * Copyright 2014 Mirantis, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain
 * a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
**/
define([
    // dependency on jQuery is still needed because:
    // 1) we still have some Backbone code which uses $().i18n()
    // 2) it seems to be impossible to use AMD version with jQuery extensions
    'jquery',
    'underscore',
    'i18next',
    'json!translations/core.json'
], function($, _, i18next, translations) {
    'use strict';

    var defaultLocale = 'en-US';

    var i18n = _.extend(_.bind(i18next.t, i18next), {
        getLocaleName: function(locale) {
            return i18n('language', {lng: locale});
        },
        getLanguageName: function(locale) {
            return i18n('language_name', {lng: locale});
        },
        getAvailableLocales: function() {
            return _.keys(translations).sort();
        },
        getCurrentLocale: function() {
            return i18next.lng();
        },
        setLocale: function(locale) {
            i18next.setLng(locale, {});
        }
    });

    i18next.init({resStore: translations, fallbackLng: defaultLocale});

    // reset locale to default if current locale is not available
    if (!_.contains(i18n.getAvailableLocales(), i18n.getCurrentLocale())) {
        i18n.setLocale(defaultLocale);
    }

    // export global i18n variable to use in templates
    window.i18n = i18n;

    return i18n;
});

==> nailgun_8.0.0.orig.tar.gz: nailgun/static/i18n.js <==
/*
 * Copyright 2014 Mirantis, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain
 * a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
**/
define([
    'underscore',
    'i18next-client',
    './translations/core.json'
], function(_, i18next, translations) {
    'use strict';

    var defaultLocale = 'en-US';

    var i18n = _.extend(_.bind(i18next.t, i18next), {
        getLocaleName: function(locale) {
            return i18n('language', {lng: locale});
        },
        getLanguageName: function(locale) {
            return i18n('language_name', {lng: locale});
        },
        getAvailableLocales: function() {
            return _.keys(translations).sort();
        },
        getCurrentLocale: function() {
            return i18next.lng();
        },
        setLocale: function(locale) {
            i18next.setLng(locale, {});
        },
        addTranslations: function(extraTranslations) {
            _.merge(i18next.options.resStore, extraTranslations);
        }
    });

    i18next.init({resStore: translations, fallbackLng: defaultLocale});

    // reset locale to default if current locale is not available
    if (!_.contains(i18n.getAvailableLocales(), i18n.getCurrentLocale())) {
        i18n.setLocale(defaultLocale);
    }

    // export global i18n variable to use in templates
    window.i18n = i18n;

    return i18n;
});
